#!/usr/bin/env python3
# !/usr/bin/env python3
# coding: utf-8


import os.path
import re
import time

import yaml


def tindex(sequence, period, count=None):
    n = len(sequence)
    idx = int(time.time() / period)
    if not count:
        return sequence[idx % n]
    count = min(n, count)
    idx = idx * count
    return [sequence[i % n] for i in range(idx, idx + count)]


def load_standard_contextmap(path, extra_path):
    ctxmap = yaml.load(open(path))
    extra = {}
    for key, val in ctxmap.items():
        if not isinstance(val, str):
            continue
        if re.match(r'\.\w+', val):
            val = key + val
        p = os.path.join(extra_path, val)
        extra[key] = yaml.load(open(p))
    ctxmap.update(extra)
    return ctxmap



#!/usr/bin/env python3
# coding: utf-8
import os
import re

from setuptools import setup, find_packages

# import joker; exit(1)
# DO NOT import your package from your setup.py


namespace = 'm14'
package_name = 'default'
description = 'locate m14 default dir'


def read(filename):
    with open(filename) as f:
        return f.read()


def version_find():
    if namespace:
        path = '{}/{}/__init__.py'.format(namespace, package_name)
    else:
        path = '{}/__init__.py'.format(package_name)
    root = os.path.dirname(__file__)
    path = os.path.join(root, path)
    regex = re.compile(
        r'''^__version__\s*=\s*('|"|'{3}|"{3})([.\w]+)\1\s*(#|$)''')
    # print('path', path)
    with open(path) as fin:
        for line in fin:
            line = line.strip()
            if not line or line.startswith('#'):
                continue
            mat = regex.match(line)
            if mat:
                return mat.groups()[1]
    raise ValueError('__version__ definition not found')


config = {
    'name': "m14",
    'version': version_find(),
    'description': '' + description,
    'keywords': 'm14',
    'url': "",
    'author': 'frozflame',
    'author_email': 'frozflame@outlook.com',
    'license': "GNU General Public License (GPL)",
    'packages': find_packages(),
    'namespace_packages': ["m14"],
    'zip_safe': False,
    'install_requires': read("requirements.txt"),
    'classifiers': [
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.0',
        'Programming Language :: Python :: 3.1',
        'Programming Language :: Python :: 3.2',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
    ],

    # ensure copy static file to runtime directory
    'include_package_data': True,
}

setup(**config)



#!/usr/bin/env python3
# coding: utf-8

from __future__ import unicode_literals

import os.path

import yaml

__version__ = '0.0.6'


def _load_conf():
    from joker.default import under_home_dir
    paths = [under_home_dir('.m14-default.yml'), '/etc/m14-default.yml']
    for path in paths:
        if os.path.isfile(path):
            return yaml.load(open(path))
    return {}


def under_default_dir(package, *paths):
    conf = _load_conf()
    name = getattr(package, '__name__', str(package)).split('.')[-1]
    try:
        dir_ = conf[name]
    except LookupError:
        dir_ = os.path.join(conf.get('default', '/data'), name)
    return os.path.join(dir_, *paths)


